@@ -1,7 +1,28 @@
+"""
+Copyright 2020 - 2023 Dennis Rohde
+
+Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""
 from .backend import *
+from .stabbing import stabbing_path as _stabbing_path
 
 config = Config()
 
+def _optimize_centers(self, curves, consecutive_call=False):
+    if curves.dimensions < 2:
+        print("this method only works for curves of at least two dimensions!")
+        return
+    all_balls = self.compute_center_enclosing_balls(curves, False)
+    for i, center_balls in enumerate(all_balls):
+        path, _ = _stabbing_path(center_balls)
+        self[i] = Curve(path, "center {}".format(i))
+
+Clustering_Result.optimize_centers = _optimize_centers
+
 def plot_curve(*curves, vertex_markings=True, savename=None, saveextension=None, return_fig=False, legend=True):
     import matplotlib.pyplot as plt
     from mpl_toolkits.mplot3d import Axes3D
